@@ -1,3 +1,6 @@
+#ifndef QT_FEATURES_GlobalConfig_src_corelib_global_qconfig_p_h_H
+#define QT_FEATURES_GlobalConfig_src_corelib_global_qconfig_p_h_H
+
 #define QT_FEATURE_use_bfd_linker -1
 
 #define QT_FEATURE_use_gold_linker -1
@@ -22,55 +25,55 @@
 
 #define QT_FEATURE_reduce_exports 1
 
-#define QT_FEATURE_no_direct_extern_access 1
+#define QT_FEATURE_no_direct_extern_access -1
 
-#define QT_FEATURE_x86intrin 1
+#define QT_FEATURE_x86intrin -1
 
-#define QT_FEATURE_sse2 1
+#define QT_FEATURE_sse2 -1
 
-#define QT_FEATURE_sse3 1
+#define QT_FEATURE_sse3 -1
 
-#define QT_FEATURE_ssse3 1
+#define QT_FEATURE_ssse3 -1
 
-#define QT_FEATURE_sse4_1 1
+#define QT_FEATURE_sse4_1 -1
 
-#define QT_FEATURE_sse4_2 1
+#define QT_FEATURE_sse4_2 -1
 
-#define QT_FEATURE_avx 1
+#define QT_FEATURE_avx -1
 
-#define QT_FEATURE_f16c 1
+#define QT_FEATURE_f16c -1
 
-#define QT_FEATURE_avx2 1
+#define QT_FEATURE_avx2 -1
 
-#define QT_FEATURE_avx512f 1
+#define QT_FEATURE_avx512f -1
 
-#define QT_FEATURE_avx512er 1
+#define QT_FEATURE_avx512er -1
 
-#define QT_FEATURE_avx512cd 1
+#define QT_FEATURE_avx512cd -1
 
-#define QT_FEATURE_avx512pf 1
+#define QT_FEATURE_avx512pf -1
 
-#define QT_FEATURE_avx512dq 1
+#define QT_FEATURE_avx512dq -1
 
-#define QT_FEATURE_avx512bw 1
+#define QT_FEATURE_avx512bw -1
 
-#define QT_FEATURE_avx512vl 1
+#define QT_FEATURE_avx512vl -1
 
-#define QT_FEATURE_avx512ifma 1
+#define QT_FEATURE_avx512ifma -1
 
-#define QT_FEATURE_avx512vbmi 1
+#define QT_FEATURE_avx512vbmi -1
 
-#define QT_FEATURE_avx512vbmi2 1
+#define QT_FEATURE_avx512vbmi2 -1
 
-#define QT_FEATURE_aesni 1
+#define QT_FEATURE_aesni -1
 
-#define QT_FEATURE_vaes 1
+#define QT_FEATURE_vaes -1
 
-#define QT_FEATURE_rdrnd 1
+#define QT_FEATURE_rdrnd -1
 
-#define QT_FEATURE_rdseed 1
+#define QT_FEATURE_rdseed -1
 
-#define QT_FEATURE_shani 1
+#define QT_FEATURE_shani -1
 
 #define QT_FEATURE_lsx -1
 
@@ -80,13 +83,13 @@
 
 #define QT_FEATURE_mips_dspr2 -1
 
-#define QT_FEATURE_neon -1
+#define QT_FEATURE_neon 1
 
-#define QT_FEATURE_arm_crc32 -1
+#define QT_FEATURE_arm_crc32 1
 
-#define QT_FEATURE_arm_crypto -1
+#define QT_FEATURE_arm_crypto 1
 
-#define QT_FEATURE_arm_sve -1
+#define QT_FEATURE_arm_sve 1
 
 #define QT_FEATURE_localtime_r 1
 
@@ -144,3 +147,5 @@
 
 #define QT_FEATURE_relro_now_linker -1
 
+
+#endif // QT_FEATURES_GlobalConfig_src_corelib_global_qconfig_p_h_H
