@@ -1,5 +1,10 @@
+#ifndef QT_FEATURES_Core_src_corelib_qtcore_config_p_h_H
+#define QT_FEATURES_Core_src_corelib_qtcore_config_p_h_H
+
 #define QT_FEATURE_clock_gettime 1
 
+#define QT_FEATURE_copy_file_range 1
+
 #define QT_FEATURE_doubleconversion 1
 
 #define QT_FEATURE_system_doubleconversion 1
@@ -18,8 +23,12 @@
 
 #define QT_FEATURE_icu -1
 
+#define QT_FEATURE_winsdkicu -1
+
 #define QT_FEATURE_inotify 1
 
+#define QT_FEATURE_jemalloc -1
+
 #define QT_FEATURE_journald -1
 
 #define QT_FEATURE_system_libb2 1
@@ -98,3 +107,5 @@
 
 #define QT_FEATURE_openssl_hash -1
 
+
+#endif // QT_FEATURES_Core_src_corelib_qtcore_config_p_h_H
