@@ -1,4 +1,7 @@
-#define QT_FEATURE_accessibility_atspi_bridge -1
+#ifndef QT_FEATURES_Gui_src_gui_qtgui_config_p_h_H
+#define QT_FEATURES_Gui_src_gui_qtgui_config_p_h_H
+
+#define QT_FEATURE_accessibility_atspi_bridge 1
 
 #define QT_FEATURE_directfb -1
 
@@ -54,9 +57,9 @@
 
 #define QT_FEATURE_vkgen 1
 
-#define QT_FEATURE_vkkhrdisplay -1
+#define QT_FEATURE_vkkhrdisplay 1
 
-#define QT_FEATURE_egl_x11 -1
+#define QT_FEATURE_egl_x11 1
 
 #define QT_FEATURE_eglfs -1
 
@@ -98,9 +101,9 @@
 
 #define QT_FEATURE_tuiotouch 1
 
-#define QT_FEATURE_xcb_glx -1
+#define QT_FEATURE_xcb_glx 1
 
-#define QT_FEATURE_xcb_egl_plugin -1
+#define QT_FEATURE_xcb_egl_plugin 1
 
 #define QT_FEATURE_xcb_native_painting -1
 
@@ -128,5 +131,37 @@
 
 #define QT_FEATURE_graphicsframecapture -1
 
-#define QT_FEATURE_run_opengl_tests -1
+#define QT_FEATURE_wayland_client 1
 
+#define QT_FEATURE_wayland_server 1
+
+#define QT_FEATURE_wayland_egl 1
+
+#define QT_FEATURE_wayland_brcm -1
+
+#define QT_FEATURE_wayland_drm_egl_server_buffer 1
+
+#define QT_FEATURE_wayland_libhybris_egl_server_buffer -1
+
+#define QT_FEATURE_wayland_dmabuf_server_buffer 1
+
+#define QT_FEATURE_wayland_shm_emulation_server_buffer 1
+
+#define QT_FEATURE_wayland_vulkan_server_buffer 1
+
+#define QT_FEATURE_wayland_datadevice 1
+
+#define QT_FEATURE_wayland_client_primary_selection 1
+
+#define QT_FEATURE_wayland_client_fullscreen_shell_v1 1
+
+#define QT_FEATURE_wayland_client_wl_shell 1
+
+#define QT_FEATURE_wayland_client_xdg_shell 1
+
+#define QT_FEATURE_egl_extension_platform_wayland 1
+
+#define QT_FEATURE_run_opengl_tests 1
+
+
+#endif // QT_FEATURES_Gui_src_gui_qtgui_config_p_h_H
