@@ -1,3 +1,6 @@
+#ifndef QT_FEATURES_Gui_src_gui_qtgui_config_h_H
+#define QT_FEATURES_Gui_src_gui_qtgui_config_h_H
+
 #define QT_FEATURE_accessibility_atspi_bridge -1
 
 #define QT_FEATURE_emojisegmenter 1
@@ -112,6 +115,10 @@
 
 #define QT_FEATURE_wayland -1
 
+#define QT_FEATURE_waylandscanner -1
+
 #define QT_NO_ACCESSIBILITY_ATSPI_BRIDGE 1
 #define QT_NO_OPENGL 1
 #define QT_NO_EGL 1
+
+#endif // QT_FEATURES_Gui_src_gui_qtgui_config_h_H
