@@ -1,3 +1,6 @@
+#ifndef QT_FEATURES_Network_src_network_qtnetwork_config_p_h_H
+#define QT_FEATURES_Network_src_network_qtnetwork_config_p_h_H
+
 #define QT_FEATURE_libresolv 1
 
 #define QT_FEATURE_libproxy -1
@@ -14,3 +17,5 @@
 
 #define QT_FEATURE_publicsuffix_system 1
 
+
+#endif // QT_FEATURES_Network_src_network_qtnetwork_config_p_h_H
